# CHANGE LOG

## 1.0.0
Feature release. 
* Refactored catalog configuration API.
* Support for aggregate functions and binning in DataPath API.
* Various bug fixes.
* Complete change list [here](https://github.com/informatics-isi-edu/deriva-py/compare/v0.9.0...v1.0.0). 

Change lists for previous releases can be found on the GitHub releases 
page [here](https://github.com/informatics-isi-edu/deriva-py/releases).